@@ -35,7 +35,7 @@
 #include <e2k-restriction.h>
 #include <e2k-utils.h>
 
-#define d(x) x
+#define d(x)
 
 /* Placeholder for each component and its recurrences */
 typedef struct {
@@ -834,6 +834,9 @@ get_changed_tasks (ECalBackendExchange *cbex)
 	status = e2k_result_iter_free (iter);
 
 	if (!SOUP_STATUS_IS_SUCCESSFUL (status)) {
+		if (!since)
+			e_cal_backend_exchange_cache_sync_end (cbex);
+
 		g_ptr_array_free (hrefs, TRUE);
 		g_hash_table_destroy (modtimes);
 		g_hash_table_destroy (attachments);
@@ -865,6 +868,8 @@ get_changed_tasks (ECalBackendExchange *cbex)
 
 	while ((result = e2k_result_iter_next (iter))) {
 		GByteArray *ical_data;
+
+		/* XXX e2k_properties_get_prop() ought to return a GString. */
 		ical_data = e2k_properties_get_prop (result->props, PR_INTERNET_CONTENT);
 		if (!ical_data) {
 			g_ptr_array_add (hrefs, g_strdup (result->href));
@@ -876,7 +881,7 @@ get_changed_tasks (ECalBackendExchange *cbex)
 		
 		e_cal_backend_exchange_cache_lock (cbex);
 		ecalbexcomp = get_exchange_comp (cbex, uid);
-		attachment_list = get_attachment (cbex, uid, ical_data->data, ical_data->len);
+		attachment_list = get_attachment (cbex, uid, (char *) ical_data->data, ical_data->len);
 		if (attachment_list) {
 			ecomp = e_cal_component_new ();
 			e_cal_component_set_icalcomponent (ecomp, icalcomponent_new_clone (ecalbexcomp->icomp));
